@@ -1,6 +1,6 @@
 package Dist::Zilla::App::Command::debuild;
 BEGIN {
-  $Dist::Zilla::App::Command::debuild::VERSION = '0.01';
+  $Dist::Zilla::App::Command::debuild::VERSION = '0.02';
 }
 
 use strict;
@@ -14,7 +14,17 @@ use autodie qw(:all);
 
 sub abstract { 'build debian package' }
 
-sub opt_spec {}
+sub opt_spec {
+    # these options are propagated to debuild mostly for the tests
+    # note than they should be specified as --us and will be transformed to -us because of getopt parsing differences
+    ['us'   => "do not sign the source package"],
+    ['uc'   => "do not sign the .changes file"],
+}
+
+sub validate_args {
+    my ($self, $opt, $args) = @_;
+    die 'no args expected' if @$args;
+}
 
 sub execute {
     my ($self, $opt, $args) = @_;
@@ -22,7 +32,10 @@ sub execute {
     system('rm -rf debuild');
     mkdir('debuild');
     $self->zilla->build_in('debuild/source');
-    system('cd debuild/source && debuild');
+    my @debuild_args;
+    push @debuild_args, '-us' if $opt->{us};
+    push @debuild_args, '-uc' if $opt->{uc};
+    system("cd debuild/source && debuild @debuild_args");
 }
 
 1;
@@ -36,7 +49,7 @@ Dist::Zilla::App::Command::debuild - build debian package
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
